@@ -59,8 +59,7 @@ KORGANIZERPRIVATE_EXPORT QColor resourceColor(const Akonadi::Item &incidence);
 
 KORGANIZERPRIVATE_EXPORT QColor resourceColor(const Akonadi::Collection &collection);
 KORGANIZERPRIVATE_EXPORT QColor resourceColorKnown(const Akonadi::Collection &collection);
-KORGANIZERPRIVATE_EXPORT void setResourceColor(const Akonadi::Collection &collection,
-                                               const QColor &color);
+KORGANIZERPRIVATE_EXPORT void setResourceColor(const Akonadi::Collection &collection, const QColor &color);
 
 /**
   Returns the number of years between the @p start QDate and the @p end QDate
