@@ -90,8 +90,7 @@ SummaryEventInfo::SummaryEventInfo()
 }
 
 /**static*/
-SummaryEventInfo::List SummaryEventInfo::eventsForRange(const QDate &start, const QDate &end,
-                                                        const Akonadi::ETMCalendar::Ptr &calendar)
+SummaryEventInfo::List SummaryEventInfo::eventsForRange(const QDate &start, const QDate &end, const Akonadi::ETMCalendar::Ptr &calendar)
 {
     KCalCore::Event::List allEvents = calendar->events();
     KCalCore::Event::List events;
@@ -291,8 +290,7 @@ SummaryEventInfo::List SummaryEventInfo::eventsForRange(const QDate &start, cons
     return eventInfoList;
 }
 
-SummaryEventInfo::List SummaryEventInfo::eventsForDate(const QDate &date,
-                                                       const Akonadi::ETMCalendar::Ptr &calendar)
+SummaryEventInfo::List SummaryEventInfo::eventsForDate(const QDate &date, const Akonadi::ETMCalendar::Ptr &calendar)
 {
     return eventsForRange(date, date, calendar);
 }
