@@ -120,7 +120,7 @@ SDSummaryWidget::SDSummaryWidget(KontactInterface::Plugin *plugin, QWidget *pare
     // Create the Summary Layout
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     mainLayout->setSpacing(3);
-    mainLayout->setMargin(3);
+    mainLayout->setContentsMargins(3, 3, 3, 3);
 
     QWidget *header = createHeader(this,
                                    QStringLiteral("view-calendar-special-occasion"),
@@ -577,8 +577,8 @@ void SDSummaryWidget::createLabels()
             }
 
             // Age
-            if ((*addrIt).category == CategoryBirthday ||
-                (*addrIt).category == CategoryAnniversary) {
+            if ((*addrIt).category == CategoryBirthday
+                || (*addrIt).category == CategoryAnniversary) {
                 label = new QLabel(this);
                 if ((*addrIt).yearsOld <= 0) {
                     label->setText(QString());
